@@ -22,6 +22,8 @@
 #' @inheritParams density_at
 #' @inheritParams pd
 #'
+#' @inheritSection hdi Model components
+#'
 #' @examplesIf require("rstanarm") && require("emmeans") && require("brms") && require("BayesFactor")
 #' library(bayestestR)
 #'
@@ -79,7 +81,6 @@ p_map <- function(x, ...) {
 p_pointnull <- p_map
 
 
-
 #' @rdname p_map
 #' @export
 p_map.numeric <- function(x, null = 0, precision = 2^10, method = "kernel", ...) {
@@ -160,7 +161,6 @@ p_map.data.frame <- function(x, null = 0, precision = 2^10, method = "kernel", r
 }
 
 
-
 #' @export
 p_map.draws <- function(x, null = 0, precision = 2^10, method = "kernel", ...) {
   p_map(.posterior_draws_to_df(x), null = null, precision = precision, method = method, ...)
@@ -170,7 +170,6 @@ p_map.draws <- function(x, null = 0, precision = 2^10, method = "kernel", ...) {
 p_map.rvar <- p_map.draws
 
 
-
 #' @export
 p_map.emmGrid <- function(x, null = 0, precision = 2^10, method = "kernel", ...) {
   xdf <- insight::get_parameters(x)
@@ -216,10 +215,13 @@ p_map.predictions <- p_map.slopes
 }
 
 
-
-
 #' @export
-p_map.mcmc <- function(x, null = 0, precision = 2^10, method = "kernel", parameters = NULL, ...) {
+p_map.mcmc <- function(x,
+                       null = 0,
+                       precision = 2^10,
+                       method = "kernel",
+                       parameters = NULL,
+                       ...) {
   out <- .p_map_models(
     x = x,
     null = null,
@@ -249,11 +251,14 @@ p_map.mcmc.list <- p_map.mcmc
 p_map.BGGM <- p_map.mcmc
 
 
-
 #' @export
-p_map.bamlss <- function(x, null = 0, precision = 2^10, method = "kernel",
-                         component = c("all", "conditional", "location"), parameters = NULL, ...) {
-  component <- match.arg(component)
+p_map.bamlss <- function(x,
+                         null = 0,
+                         precision = 2^10,
+                         method = "kernel",
+                         component = "all",
+                         parameters = NULL,
+                         ...) {
   out <- .p_map_models(
     x = x,
     null = null,
@@ -271,12 +276,14 @@ p_map.bamlss <- function(x, null = 0, precision = 2^10, method = "kernel",
 }
 
 
-
 #' @export
-p_map.sim.merMod <- function(x, null = 0, precision = 2^10, method = "kernel",
-                             effects = c("fixed", "random", "all"), parameters = NULL, ...) {
-  effects <- match.arg(effects)
-
+p_map.sim.merMod <- function(x,
+                             null = 0,
+                             precision = 2^10,
+                             method = "kernel",
+                             effects = "fixed",
+                             parameters = NULL,
+                             ...) {
   out <- .p_map_models(
     x = x,
     null = null,
@@ -288,13 +295,15 @@ p_map.sim.merMod <- function(x, null = 0, precision = 2^10, method = "kernel",
     ...
   )
 
-  attr(out, "data") <- insight::get_parameters(x, effects = effects, parameters = parameters)
+  attr(out, "data") <- insight::get_parameters(
+    x,
+    effects = effects,
+    parameters = parameters
+  )
   out
 }
 
 
-
-
 #' @export
 p_map.sim <- function(x, null = 0, precision = 2^10, method = "kernel",
                       parameters = NULL, ...) {
@@ -314,16 +323,15 @@ p_map.sim <- function(x, null = 0, precision = 2^10, method = "kernel",
 }
 
 
-
-
-#' @rdname p_map
 #' @export
-p_map.stanreg <- function(x, null = 0, precision = 2^10, method = "kernel",
-                          effects = c("fixed", "random", "all"),
-                          component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
-                          parameters = NULL, ...) {
-  effects <- match.arg(effects)
-  component <- match.arg(component)
+p_map.stanreg <- function(x,
+                          null = 0,
+                          precision = 2^10,
+                          method = "kernel",
+                          effects = "fixed",
+                          component = "location",
+                          parameters = NULL,
+                          ...) {
   cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
@@ -356,15 +364,16 @@ p_map.stanfit <- p_map.stanreg
 p_map.blavaan <- p_map.stanreg
 
 
-
 #' @rdname p_map
 #' @export
-p_map.brmsfit <- function(x, null = 0, precision = 2^10, method = "kernel",
-                          effects = c("fixed", "random", "all"),
-                          component = c("conditional", "zi", "zero_inflated", "all"),
-                          parameters = NULL, ...) {
-  effects <- match.arg(effects)
-  component <- match.arg(component)
+p_map.brmsfit <- function(x,
+                          null = 0,
+                          precision = 2^10,
+                          method = "kernel",
+                          effects = "fixed",
+                          component = "conditional",
+                          parameters = NULL,
+                          ...) {
   cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
@@ -373,7 +382,8 @@ p_map.brmsfit <- function(x, null = 0, precision = 2^10, method = "kernel",
         x,
         effects = effects,
         component = component,
-        parameters = parameters
+        parameters = parameters,
+        ...
       ),
       null = null,
       precision = precision,
@@ -390,9 +400,6 @@ p_map.brmsfit <- function(x, null = 0, precision = 2^10, method = "kernel",
 }
 
 
-
-
-
 #' @export
 p_map.BFBayesFactor <- function(x, null = 0, precision = 2^10, method = "kernel", ...) {
   out <- p_map(insight::get_parameters(x), null = null, precision = precision, method = method, ...)
@@ -401,7 +408,6 @@ p_map.BFBayesFactor <- function(x, null = 0, precision = 2^10, method = "kernel"
 }
 
 
-
 #' @export
 p_map.MCMCglmm <- function(x, null = 0, precision = 2^10, method = "kernel", ...) {
   nF <- x$Fixed$nfl
@@ -411,7 +417,6 @@ p_map.MCMCglmm <- function(x, null = 0, precision = 2^10, method = "kernel", ...
 }
 
 
-
 #' @export
 p_map.bayesQR <- function(x, null = 0, precision = 2^10, method = "kernel", ...) {
   out <- p_map(insight::get_parameters(x), null = null, precision = precision, method = method, ...)
