@@ -222,15 +222,24 @@
 #' @keywords internal
 .append_datagrid.emmGrid <- function(results, object, long = FALSE) {
   # results is assumed to be a data frame with "Parameter" column
-  # object is an emmeans / marginalefeects that results is based on
+  # object is an emmeans / marginaleffects that results is based on
 
   all_attrs <- attributes(results) # save attributes for later
   all_class <- class(results)
 
+  # extract model info. if we have categorical, add "group" variable
+  model <- attributes(object)$model
+  if (!long && !is.null(model)) {
+    m_info <- insight::model_info(model, response = 1, verbose = FALSE)
+    if (!is.null(m_info) && (m_info$is_categorical || m_info$is_ordinal || m_info$is_cumulative || isTRUE(insight::is_multivariate(model))) && "group" %in% colnames(object)) { # nolint
+      results <- .safe(cbind(data.frame(group = object$group), results), results)
+    }
+  }
+
   datagrid <- insight::get_datagrid(object)
   grid_names <- colnames(datagrid)
 
-  if (long) {
+  if (long || nrow(datagrid) < nrow(results)) {
     datagrid$Parameter <- unique(results$Parameter)
     results <- datawizard::data_merge(datagrid, results, by = "Parameter")
     results$Parameter <- NULL
@@ -245,8 +254,6 @@
     attributes(results)[names(most_attrs)] <- most_attrs
   }
 
-
-
   attr(results, "idvars") <- grid_names
   results
 }
@@ -270,7 +277,7 @@
   grid_names <- colnames(object)[!is_rvar]
   datagrid <- data.frame(object[, grid_names, drop = FALSE])
 
-  if (long) {
+  if (long || nrow(datagrid) < nrow(results)) {
     datagrid$Parameter <- unique(results$Parameter)
     results <- datawizard::data_merge(datagrid, results, by = "Parameter")
     results$Parameter <- NULL
@@ -293,8 +300,8 @@
 #' @keywords internal
 .get_marginaleffects_draws <- function(object) {
   # errors and checks are handled by marginaleffects
-  insight::check_if_installed("marginaleffects")
-  data.frame(marginaleffects::posterior_draws(object, shape = "DxP"))
+  insight::check_if_installed("marginaleffects", minimum_version = "0.24.0")
+  data.frame(marginaleffects::get_draws(object, shape = "DxP"))
 }
 
 #' @keywords internal
